# 玖奕开源库

### 目录结构说明

- jy_xxx文件夹，库的源码目录，注意在__init__.py文件中配置版本号
- .pypirc文件，库的上传源、用户名、密码等；
- pyproject.toml文件，库的基本信息，作者等；
- LICENSE文件，许可证
- README.md文件，库的说明文档
- publish-pypi.sh文件，官方源发布脚本；
- publish-jypi.sh文件，玖奕源发布脚本；
- publish-test.sh文件，测试源发布脚本；
